Wrapper to fit various network embedding methods
fit_network_embedding.RdWrapper to fit various network embedding methods
Usage
fit_network_embedding(
A,
ndim = 2,
method = c("adjacency", "laplacian", "score"),
regularization = 0.5,
varimax_rotation = FALSE
)Value
A list containing the following components:
X: A list of matrices, each corresponding to a method inmethod, where each matrix hasndimcolumns representing the embedding.eval_ls: A list of eigenvalues corresponding to each method inmethod.method: The method(s) used for embedding.regularization: The regularization parameter used for the adjacency matrix.
Examples
data(example_data)
embedding_fit <- fit_network_embedding(
example_data$A, ndim = 2, method = "laplacian"
)